# Curvey
Pythonic geometric processing of discrete planar closed curves

## Installation
```shell
pip install curvey
```

## Documentation
Tutorials and API documentation hosted [here](https://darikg.github.io/curvey/)

## Highlights

### Quick visualizations

<img src="https://github.com/darikg/curvey/blob/main/static/curve_plot.png" alt="drawing" width="400"/>

Everything's numpy-, scipy-, and matplotlib-based.

### Curvature flows

<img src="https://github.com/darikg/curvey/blob/main/static/willmore_flow.png" alt="drawing" width="400"/>

Implementations of curve-shortening flow, [singularity free mean curvature flow](
https://arxiv.org/abs/1203.6819), and [Willmore flow](
https://www.cs.cmu.edu/~kmcrane/Projects/ConformalWillmoreFlow/paper.pdf).

### Shape blending

<img src="https://github.com/darikg/curvey/blob/main/static/curv_interp.png" alt="drawing" width="500"/>

Implementations of linear shape blending and [curvature flow shape blending](
https://www.sciencedirect.com/science/article/pii/S016783961730016X).
